pub enum CdxmlError {
UnknownAtomicNumber(u32),
UnknownAtomRef(String),
MissingBondEndpoint,
InvalidCoords(String),
TooManyAtoms(usize),
}Expand description
Error returned when parsing a CDXML document fails.
Variants
UnknownAtomicNumber(u32)
An atom Element attribute contained an unknown atomic number.
UnknownAtomRef(String)
A bond referenced an atom id that was not defined.
MissingBondEndpoint
A <b> bond element is missing a B or E attribute.
InvalidCoords(String)
The p coordinate attribute could not be parsed.
TooManyAtoms(usize)
The document contains more atoms than the parser’s safety limit.