parse_cdxml_all

Function parse_cdxml_all 

pub fn parse_cdxml_all(
    input: &str,
) -> Result<Vec<(Molecule, Vec<(f64, f64)>)>, CdxmlError>
Parse all molecular fragments from a CDXML document.

Each <fragment> element in the document is parsed as a separate molecule. Returns a Vec of (Molecule, 2D-coords) pairs in document order. Coordinates are in CDXML point units (1/72 inch).

Stereochemistry

Wedge bonds are derived from the Display attribute of <b> elements: "WedgeBegin" / "WedgedHashBegin" โ†’ BondOrder::Up; "Hash" / "Dash" / "WedgeEnd" / "WedgedHashEnd" โ†’ BondOrder::Down.